param(
     [Parameter()]
     [string]$spacename,

     [Parameter()]
     [string]$foldername
 )

 #call from Qlik Sense Client-Managed using external tasks in QMC
 #example:
 #path >> c:\windows\system32\windowspowershell\v1.0\powershell.exe
 #parameters >> -File "C:\Users\Qlik\Desktop\QlikMigrationPlaybook\uploadqlikclouddata.ps1" myspacename "C:\Users\Qlik\Desktop\QlikMigrationPlaybook\testing3.txt"

#set the working directory for the Migration Playbook
cd "C:\Users\Qlik\Desktop\QlikMigrationPlaybook"

$ts = Get-Date -Format "yyyy_MM_dd_HH_mm_ss"
Start-Transcript -Path ".\Logs\uploadfolder_$ts.txt"

. .\0_globals.ps1

.\qlik context use $QlikSaaSContext

$spaceId = .\qlik space filter --names $spacename -q
$connectionId = .\qlik data-file connection ls --spaceId $spaceId -q
Write-Host "Folder: $foldername, spacename: $spacename, spaceid: $spaceId, connectionId: $connectionId"

Get-ChildItem $foldername\* -Recurse -Include *.qvd, *.xlsx, *.xls, *.xlw, *.xlsm, *.xml, *.csv, *.txt, *.tab, *.qvo, *.skv, *.log, *.html, *.htm, *.kml, *.fix, *.dat, *.qvx, *.prn, *.php, *.qvs |
ForEach-Object {
   $filename = $_.FullName
   $name = Split-Path $_.FullName -Leaf
   $folders = Split-Path $_.FullName -parent | Split-Path -noqualifier
   $path = Split-Path $_.FullName -noqualifier
      
   Write-Host "Moving: $filename"
   Write-Host "Qualifier: $folders"
   Write-Host "Qualifier: $path"


   #check if exists
    $fileid = .\qlik data-file ls --connectionId $connectionId --name $name -q
    Write-Host "fileid: $fileid"
    if($fileid)
    {
        Write-Host "Updating File"
        .\qlik data-file update $fileid --file $filename --name $path --connectionId $connectionId
    }
    else
    {
        Write-Host "New File"
        .\qlik data-file create --file $filename --name $path --connectionId $connectionId --json
    }
}

exit 0

######



$ret = $LASTEXITCODE
Write-Host "Exit Code: $ret"
if($ret -gt 0)
{
    $ret = 8
}

Stop-Transcript

exit $ret
